AwersomeSceleton class

Inheritance

Constructors

AwersomeSceleton({Key? key, required double width, required double height, double? borderRadius, SkeletonShape shape = SkeletonShape.rectangle, Duration animationDuration = const Duration(milliseconds: 1500), Color backgroundColor = Colors.black12, Color flashColor = Colors.black26})
создает скелетон
const

Properties

animationDuration Duration
Поле animationDuration определяет продолжительность анимации скелетона
final
backgroundColor Color
Цвет фона скелетона, по умолчанию серый
final
borderRadius double?
Поле borderRadius определяет радиус закругления углов
final
flashColor Color
Цвет линии градиента, по умолчанию белый
final
hashCode int
The hash code for this object.
no setterinherited
height double
Высота скелетона
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shape SkeletonShape
Поле shape класса SkeletonShape определяет фигуру скелетона. Разные фигуры падходят под разные задачи. Например, SkeletonShape.rectangle идеально подходит для строк и полей ввода, в то время, как SkeletonShape.circle подходит для аватаров
final
width double
Длина скелетона
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited